@@ -1,4 +1,4 @@
-/* $Id: flow.cc 555 2010-05-28 18:16:49Z dreibh $
+/* $Id: flow.cc 645 2010-07-19 19:04:50Z dreibh $
  *
  * Network Performance Meter
  * Copyright (C) 2009-2010 by Thomas Dreibholz
@@ -988,7 +988,8 @@ void Flow::deactivate(const bool asyncStop)
 #warning Using shutdown() instead of sctp_sengmsg() with SCTP_EOF flag.
             const int shutdownOkay = ext_shutdown(SocketDescriptor, 2);
 #else
-            const int shutdownOkay = sctp_sendmsg(SocketDescriptor, NULL, 0, NULL, 0, 0, SCTP_EOF, 0, 0, 0);
+            const int shutdownOkay = ext_shutdown(SocketDescriptor, 2);
+//            const int shutdownOkay = sctp_sendmsg(SocketDescriptor, NULL, 0, NULL, 0, 0, SCTP_EOF, 0, 0, 0);
 #endif
             if(shutdownOkay < 0) {
                perror("WARNING: Cannut shut association down");
